@@ -34,21 +34,12 @@ bind_cols. <- function(..., .name_repair = "unique") {
 
   dots <- setDT(unlist(dots, recursive = FALSE), check.names = FALSE)
 
-  names(dots) <- vec_as_names(names(dots), repair = .name_repair)
+  dots <- df_name_repair(dots, .name_repair = .name_repair)
 
   as_tidytable(dots)
 
 }
 
-#' @export
-#' @rdname dt_verb
-#' @inheritParams bind_rows.
-dt_bind_rows <- function(..., .id = NULL) {
-  deprecate_stop("0.5.2", "tidytable::dt_bind_rows()", "bind_rows.()")
-
-  bind_rows.(..., .id = .id)
-}
-
 #' @export
 #' @rdname bind_cols.
 bind_rows. <- function(..., .id = NULL) {
@@ -64,12 +55,3 @@ bind_rows. <- function(..., .id = NULL) {
   as_tidytable(dots)
 }
 
-#' @export
-#' @rdname dt_verb
-#' @inheritParams bind_cols.
-dt_bind_cols <- function(...) {
-  deprecate_stop("0.5.2", "tidytable::dt_bind_cols()", "bind_cols.()")
-
-  bind_cols.(...)
-}
-
