@@ -49,16 +49,16 @@ distinct..data.frame <- function(.df, ..., .keep_all = FALSE) {
 
     if (!.keep_all) .df <- .df[, ..select_cols]
 
+    named_flag <- have_name(dots)
+
+    if (any(named_flag)) {
+
+      named_dots <- dots[named_flag]
+
+      .df <- rename.(.df, !!!named_dots)
+    }
   }
 
   .df
 }
 
-#' @export
-#' @rdname dt_verb
-#' @inheritParams distinct.
-dt_distinct <- function(.df, ..., .keep_all = FALSE) {
-  deprecate_stop("0.5.2", "tidytable::dt_distinct()", "distinct.()")
-
-  distinct.(.df, ..., .keep_all = .keep_all)
-}
