@@ -51,12 +51,3 @@ rename_with..data.frame <- function(.df, .fn, .cols = everything(), ...) {
     .df
   }
 }
-
-#' @export
-#' @rdname dt_verb
-#' @inheritParams rename_with.
-dt_rename_with <- function(.df, .fn, .cols = everything(), ...) {
-  deprecate_stop("0.5.2", "tidytable::dt_rename_with()", "rename_with.()")
-
-  rename_with.(.df, .fn, .cols = {{ .cols }}, ...)
-}
