@@ -52,12 +52,3 @@ select..data.frame <- function(.df, ...) {
 
   .df
 }
-
-#' @export
-#' @rdname dt_verb
-#' @inheritParams select.
-dt_select <- function(.df, ...) {
-  deprecate_stop("0.5.2", "tidytable::dt_select()", "select.()")
-
-  select.(.df, ...)
-}
