@@ -19,7 +19,7 @@ tidytable <- function(...) {
   else data_env <- env(quo_get_env(dots[[1]]))
 
   .df <- eval_quo(
-    data.table(!!!dots),
+    data.table::data.table(!!!dots),
     new_data_mask(data_env), env = caller_env()
   )
 
