@@ -1,22 +1,3 @@
-test_that("dt_fill() missings are filled correctly & is deprecated", {
-  # filled down from last non-missing
-  df <- data.table::data.table(x = c(NA, 1, NA, 2, NA, NA))
-
-  expect_deprecated(dt_fill(df, x))
-
-  out <- as_tidytable(df) %>% dt_fill(x)
-  expect_equal(out$x, c(NA, 1, 1, 2, 2, 2))
-
-  out <- as_tidytable(df) %>% dt_fill(x, .direction = "up")
-  expect_equal(out$x, c(1, 1, 2, 2, NA, NA))
-
-  out <- as_tidytable(df) %>% dt_fill(x, .direction = 'downup')
-  expect_equal(out$x, c(1, 1, 1, 2, 2, 2))
-
-  out <- as_tidytable(df) %>% dt_fill(x, .direction = 'updown')
-  expect_equal(out$x, c(1, 1, 2, 2, 2, 2))
-})
-
 test_that("missings are filled correctly", {
   # filled down from last non-missing
   df <- data.table::data.table(x = c(NA, 1, NA, 2, NA, NA))
