@@ -110,3 +110,21 @@ test_that("can pivot all cols to wide with quosure function", {
   expect_named(pivot_df, c("x", "y", "z"))
   expect_equal(nrow(pivot_df), 1)
 })
+
+test_that("can fill in missing cells", {
+  df <- tidytable(g = c(1, 2), var = c("x", "y"), val = c(1, 2))
+
+  widen <- function(...) {
+    df %>% pivot_wider.(names_from = var, values_from = val, ...)
+  }
+
+  expect_equal(widen()$x, c(1, NA))
+  expect_equal(widen(values_fill = 0)$x, c(1, 0))
+  expect_equal(widen(values_fill = list(val = 0))$x, c(1, 0))
+})
+
+test_that("values_fill only affects missing cells", {
+  df <- tidytable(g = c(1, 2), names = c("x", "y"), value = c(1, NA))
+  out <- pivot_wider.(df, names_from = names, values_from = value, values_fill = 0)
+  expect_equal(out$y, c(0, NA))
+})
