@@ -1,14 +1,3 @@
-test_that("dt_ can do group aggregation with .by", {
-  df <- tidytable(x = 1:4, y = c("a","a","a","b"))
-
-  tidytable_df <- df %>%
-    dt_summarize(avg_x = mean(x), .by = y)
-
-  datatable_df <- df[, list(avg_x = mean(x)), by = y]
-
-  expect_equal(tidytable_df, datatable_df)
-})
-
 test_that("can do group aggregation with .by", {
   df <- tidytable(x = 1:4, y = c("a","a","a","b"))
 
