@@ -1,16 +1,3 @@
-test_that("dt_ works with no wt/no .by", {
-  test_df <- data.table(x = 1:5,
-                        y = 6:10,
-                        z = c(rep("a", 3), rep("b", 2)))
-
-  top_df <- test_df %>%
-    dt_top_n(3)
-
-  expect_equal(top_df$x, 1:3)
-  expect_equal(top_df$y, 6:8)
-  expect_equal(top_df$z, rep("a", 3))
-})
-
 test_that("works with no wt/no .by", {
   test_df <- data.table(x = 1:5,
                         y = 6:10,
